#
# aoserv-profile.d - Sources all scripts in per-user or per-application profile.d directories.
# Copyright (C) 2018  AO Industries, Inc.
#     support@aoindustries.com
#     7262 Bull Pen Cir
#     Mobile, AL 36695
#
# This file is part of aoserv-profile.d.
#
# aoserv-profile.d is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# aoserv-profile.d is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with aoserv-profile.d.  If not, see <http://www.gnu.org/licenses/>.
#

#
# Sources all scripts in a per-user or per-application profile.d directory.
#
# The directory to source may be provided in the AOSERV_PROFILE_D environment
# variable.  When not provided, defaults to "$HOME/.profile.d".
#
# If the selected profile directory is not a readable directory, it is skipped.
#
# All readable scripts in the directory matching *.sh are sourced, with the
# exception for symbolic links noted below.
#
# When a script is a symbolic link and has the same target as a script in
# /etc/profile.d/*.sh (as determined by "readlink -e", the script is not
# sourced, as it is assumed to be already sourced via the standard mechanism.
# This allows for both per-user and system-wide symbolic links to the same
# profile script, without it being invoked twice.
#
# See /etc/profile
#

if [ -d "${AOSERV_PROFILE_D:-$HOME/.profile.d}" ]; then
    for i in "${AOSERV_PROFILE_D:-$HOME/.profile.d}"/*.sh ; do
        if [ -r "$i" ]; then
            # Skip if is a symbolic link that also exists as a symbolic link in /etc/profile.d
            if [ -L "$i" ]; then
                unset t
                for j in /etc/profile.d/*.sh ; do
                    if [ -L "$j" ]; then
                        # Readlink only when first needed.
                        if [ "${t:-}" = '' ]; then
                            t="$(readlink -e "$i")"
                        fi
                        if [ "$t" = "$(readlink -e "$j")" ]; then
                            continue 2
                        fi
                    fi
                done
            fi
            if [ "${-#*i}" != "$-" ]; then
                . "$i"
            else
                . "$i" >/dev/null
            fi
        fi
    done
    unset i
    unset j
    unset t
fi
